==> zio-aws-alexaforbusiness_2.12-5.17.155.1-sources.jar: zio/aws/alexaforbusiness/model/UpdateSkillGroupRequest.scala <==
package zio.aws.alexaforbusiness.model
import zio.ZIO
import zio.aws.alexaforbusiness.model.primitives.{
  SkillGroupDescription,
  SkillGroupName,
  Arn
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateSkillGroupRequest(
    skillGroupArn: Option[Arn] = None,
    skillGroupName: Option[SkillGroupName] = None,
    description: Option[SkillGroupDescription] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.alexaforbusiness.model.UpdateSkillGroupRequest = {
    import UpdateSkillGroupRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.alexaforbusiness.model.UpdateSkillGroupRequest
      .builder()
      .optionallyWith(
        skillGroupArn.map(value => Arn.unwrap(value): java.lang.String)
      )(_.skillGroupArn)
      .optionallyWith(
        skillGroupName.map(value =>
          SkillGroupName.unwrap(value): java.lang.String
        )
      )(_.skillGroupName)
      .optionallyWith(
        description.map(value =>
          SkillGroupDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .build()
  }
  def asReadOnly
      : zio.aws.alexaforbusiness.model.UpdateSkillGroupRequest.ReadOnly =
    zio.aws.alexaforbusiness.model.UpdateSkillGroupRequest.wrap(buildAwsValue())
}
object UpdateSkillGroupRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.alexaforbusiness.model.UpdateSkillGroupRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.alexaforbusiness.model.UpdateSkillGroupRequest =
      zio.aws.alexaforbusiness.model.UpdateSkillGroupRequest(
        skillGroupArn.map(value => value),
        skillGroupName.map(value => value),
        description.map(value => value)
      )
    def skillGroupArn: Option[Arn]
    def skillGroupName: Option[SkillGroupName]
    def description: Option[SkillGroupDescription]
    def getSkillGroupArn: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("skillGroupArn", skillGroupArn)
    def getSkillGroupName: ZIO[Any, AwsError, SkillGroupName] =
      AwsError.unwrapOptionField("skillGroupName", skillGroupName)
    def getDescription: ZIO[Any, AwsError, SkillGroupDescription] =
      AwsError.unwrapOptionField("description", description)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.UpdateSkillGroupRequest
  ) extends zio.aws.alexaforbusiness.model.UpdateSkillGroupRequest.ReadOnly {
    override val skillGroupArn: Option[Arn] = scala
      .Option(impl.skillGroupArn())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Arn(value))
    override val skillGroupName: Option[SkillGroupName] = scala
      .Option(impl.skillGroupName())
      .map(value =>
        zio.aws.alexaforbusiness.model.primitives.SkillGroupName(value)
      )
    override val description: Option[SkillGroupDescription] = scala
      .Option(impl.description())
      .map(value =>
        zio.aws.alexaforbusiness.model.primitives.SkillGroupDescription(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.UpdateSkillGroupRequest
  ): zio.aws.alexaforbusiness.model.UpdateSkillGroupRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-alexaforbusiness_2.12-5.17.267.6-sources.jar: zio/aws/alexaforbusiness/model/UpdateSkillGroupRequest.scala <==
package zio.aws.alexaforbusiness.model
import zio.ZIO
import zio.aws.alexaforbusiness.model.primitives.{
  SkillGroupDescription,
  SkillGroupName,
  Arn
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateSkillGroupRequest(
    skillGroupArn: Optional[Arn] = Optional.Absent,
    skillGroupName: Optional[SkillGroupName] = Optional.Absent,
    description: Optional[SkillGroupDescription] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.alexaforbusiness.model.UpdateSkillGroupRequest = {
    import UpdateSkillGroupRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.alexaforbusiness.model.UpdateSkillGroupRequest
      .builder()
      .optionallyWith(
        skillGroupArn.map(value => Arn.unwrap(value): java.lang.String)
      )(_.skillGroupArn)
      .optionallyWith(
        skillGroupName.map(value =>
          SkillGroupName.unwrap(value): java.lang.String
        )
      )(_.skillGroupName)
      .optionallyWith(
        description.map(value =>
          SkillGroupDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .build()
  }
  def asReadOnly
      : zio.aws.alexaforbusiness.model.UpdateSkillGroupRequest.ReadOnly =
    zio.aws.alexaforbusiness.model.UpdateSkillGroupRequest.wrap(buildAwsValue())
}
object UpdateSkillGroupRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.alexaforbusiness.model.UpdateSkillGroupRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.alexaforbusiness.model.UpdateSkillGroupRequest =
      zio.aws.alexaforbusiness.model.UpdateSkillGroupRequest(
        skillGroupArn.map(value => value),
        skillGroupName.map(value => value),
        description.map(value => value)
      )
    def skillGroupArn: Optional[Arn]
    def skillGroupName: Optional[SkillGroupName]
    def description: Optional[SkillGroupDescription]
    def getSkillGroupArn: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("skillGroupArn", skillGroupArn)
    def getSkillGroupName: ZIO[Any, AwsError, SkillGroupName] =
      AwsError.unwrapOptionField("skillGroupName", skillGroupName)
    def getDescription: ZIO[Any, AwsError, SkillGroupDescription] =
      AwsError.unwrapOptionField("description", description)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.UpdateSkillGroupRequest
  ) extends zio.aws.alexaforbusiness.model.UpdateSkillGroupRequest.ReadOnly {
    override val skillGroupArn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.skillGroupArn())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Arn(value))
    override val skillGroupName: Optional[SkillGroupName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.skillGroupName())
        .map(value =>
          zio.aws.alexaforbusiness.model.primitives.SkillGroupName(value)
        )
    override val description: Optional[SkillGroupDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value =>
          zio.aws.alexaforbusiness.model.primitives.SkillGroupDescription(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.UpdateSkillGroupRequest
  ): zio.aws.alexaforbusiness.model.UpdateSkillGroupRequest.ReadOnly =
    new Wrapper(impl)
}
